@@ -130,61 +130,70 @@ class EVA:
     def data(self) -> pd.Series:
         return self.__data
 
-    def __get_extremes_attribute(self, attribute_name: str):
-        value = getattr(self, f"_EVA__{attribute_name}")
-        if value is None:
+    @property
+    def extremes(self) -> pd.Series:
+        if self.__extremes is None:
             raise AttributeError(
                 "extreme values must first be extracted "
                 "using the '.get_extremes' method"
             )
-        else:
-            return value
-
-    @property
-    def extremes(self) -> pd.Series:
-        return self.__get_extremes_attribute("extremes")
+        return self.__extremes
 
     @property
     def extremes_method(self) -> str:
-        return self.__get_extremes_attribute("extremes_method")
+        if self.__extremes_method is None:
+            raise AttributeError(
+                "extreme values must first be extracted "
+                "using the '.get_extremes' method"
+            )
+        return self.__extremes_method
 
     @property
     def extremes_type(self) -> str:
-        return self.__get_extremes_attribute("extremes_type")
+        if self.__extremes_type is None:
+            raise AttributeError(
+                "extreme values must first be extracted "
+                "using the '.get_extremes' method"
+            )
+        return self.__extremes_type
 
     @property
     def extremes_kwargs(self) -> dict:
-        return self.__get_extremes_attribute("extremes_kwargs")
+        if self.__extremes_kwargs is None:
+            raise AttributeError(
+                "extreme values must first be extracted "
+                "using the '.get_extremes' method"
+            )
+        return self.__extremes_kwargs
 
     @property
     def extremes_transformer(self) -> ExtremesTransformer:
-        return self.__get_extremes_attribute("extremes_transformer")
+        if self.__extremes_transformer is None:
+            raise AttributeError(
+                "extreme values must first be extracted "
+                "using the '.get_extremes' method"
+            )
+        return self.__extremes_transformer
 
-    def __get_model_attribute(self, attribute_name: typing.Optional[str] = None):
+    @property
+    def model(self) -> typing.Union[MLE, Emcee]:
         if self.__model is None:
             raise AttributeError(
                 "model must first be assigned using the '.fit_model' method"
             )
-        if attribute_name is None:
-            return self.__model
-        else:
-            return getattr(self.__model, attribute_name)
-
-    @property
-    def model(self) -> typing.Union[MLE, Emcee]:
-        return self.__get_model_attribute()
+        return self.__model
 
     @property
     def distribution(self) -> Distribution:
-        return self.__get_model_attribute("distribution")
+        return self.model.distribution
 
     @property
     def loglikelihood(self) -> float:
-        return self.__get_model_attribute("loglikelihood")
+        return self.model.loglikelihood
 
     @property
     def AIC(self) -> float:
-        return self.__get_model_attribute("AIC")
+        return self.model.AIC
 
     def test_ks(self, significance_level: float = 0.05) -> KolmogorovSmirnov:
         return KolmogorovSmirnov(
@@ -205,52 +214,32 @@ class EVA:
         lwidth = (width - len(sep)) // 2
         rwidth = width - (lwidth + len(sep))
 
-        # Function used to center text within a row
-        def center_text(text: str) -> str:
-            left_gap = (width - len(text)) // 2
-            right_gap = width - left_gap - len(text)
-            return "".join(
-                [
-                    " " * left_gap,
-                    text,
-                    " " * right_gap,
-                ]
-            )
-
         # Function used to convert label-value pair
         # into a sequence of lines within a column
-        def align_text(label: str, value: str, position: str) -> str:
+        def align_text(label: str, value: str, position: str) -> typing.List[str]:
+            assert position in ["left", "right"]
             if label == "":
                 if position == "left":
-                    return f"{value:>{lwidth}}"
-                elif position == "right":
-                    return f"{value:>{rwidth}}"
-                else:
-                    raise AssertionError
+                    return [f"{value:>{lwidth}}"]
+                return [f"{value:>{rwidth}}"]
 
             # Find width available for the value
-            # +2 stands for colon and space (label: value)
+            # (+2 stands for colon and space (label: value))
             label_width = len(label) + 2
             if position == "left":
                 free_width = lwidth - label_width
-            elif position == "right":
-                free_width = rwidth - label_width
             else:
-                raise AssertionError
+                free_width = rwidth - label_width
 
             # Split value into chunks using 'free_width'
             value_chunks = [
                 value[i : i + free_width] for i in range(0, len(value), free_width)
             ]
-            if "".join(value_chunks) != value:
-                raise AssertionError
 
             # Collect text row-by-row using 'value_chunks'
-            aligned_text = []
-            for i, chunk in enumerate(value_chunks):
-                if i == 0:
-                    aligned_text.append(f"{label}: {chunk:>{free_width}}")
-                else:
+            aligned_text = [f"{label}: {value_chunks[0]:>{free_width}}"]
+            try:
+                for chunk in value_chunks[1:]:
                     aligned_text.append(
                         "".join(
                             [
@@ -259,37 +248,26 @@ class EVA:
                             ]
                         )
                     )
-            return "\n".join(aligned_text)
+            except IndexError:
+                pass
+            return aligned_text
 
         # Function used to convert two label-value pairs
         # into a sequence of rows representing two columns
-        def align_pair(label: tuple, value: tuple) -> str:
-            # Create list of rows for each label-value pair
-            left_part = align_text(
-                label=label[0],
-                value=value[0],
-                position="left",
-            ).split("\n")
-            right_part = align_text(
-                label=label[1],
-                value=value[1],
-                position="right",
-            ).split("\n")
-
-            # Extend the shorter label-value pair column
-            delta_lines = len(left_part) - len(right_part)
-            if delta_lines < 0:
-                for _ in range(-delta_lines):
-                    left_part.append(" " * len(left_part[0]))
-            else:
-                for _ in range(delta_lines):
-                    right_part.append(" " * len(right_part[0]))
-
-            # Merge the two columns into a sequence of rows
-            return "\n".join(
-                "".join([left, sep, right])
-                for left, right in zip(left_part, right_part)
-            )
+        def align_pair(
+            label: typing.Tuple[str, str],
+            value: typing.Tuple[str, str],
+        ) -> str:
+            parts = [
+                align_text(lbl, val, pos)
+                for lbl, val, pos in zip(label, value, ("left", "right"))
+            ]
+            while len(parts[0]) != len(parts[1]):
+                shorter_part_index = 0 if len(parts[0]) < len(parts[1]) else 1
+                parts[shorter_part_index].append(
+                    " " * len(parts[shorter_part_index][0])
+                )
+            return "\n".join([sep.join([left, right]) for left, right in zip(*parts)])
 
         # Create summary header
         start_date = (
@@ -301,9 +279,9 @@ class EVA:
             f"{self.data.index[-1].year}"
         )
         summary = [
-            center_text("Univariate Extreme Value Analysis"),
+            "Univariate Extreme Value Analysis".center(width),
             "=" * width,
-            center_text("Source Data"),
+            "Source Data".center(width),
             "-" * width,
             align_pair(
                 ("Data label", "Size"),
@@ -319,7 +297,7 @@ class EVA:
         # Fill the extremes section
         summary.extend(
             [
-                center_text("Extreme Values"),
+                "Extreme Values".center(width),
                 "-" * width,
             ]
         )
@@ -355,7 +333,7 @@ class EVA:
         # Fill the model section
         summary.extend(
             [
-                center_text("Model"),
+                "Model".center(width),
                 "-" * width,
             ]
         )
@@ -485,21 +463,15 @@ class EVA:
         self.__extremes_kwargs = {}
         if method == "BM":
             self.__extremes_kwargs["block_size"] = pd.to_timedelta(
-                kwargs.pop("block_size", "365.2425D")
+                kwargs.get("block_size", "365.2425D")
             )
-            self.__extremes_kwargs["errors"] = kwargs.pop("errors", "raise")
-            self.__extremes_kwargs["min_last_block"] = kwargs.pop(
+            self.__extremes_kwargs["errors"] = kwargs.get("errors", "raise")
+            self.__extremes_kwargs["min_last_block"] = kwargs.get(
                 "min_last_block", None
             )
-        elif method == "POT":
-            self.__extremes_kwargs["threshold"] = kwargs.pop("threshold")
-            self.__extremes_kwargs["r"] = pd.to_timedelta(kwargs.pop("r", "24H"))
         else:
-            raise AssertionError
-        if len(kwargs) != 0:
-            raise TypeError(
-                f"unrecognized arguments passed in: {', '.join(kwargs.keys())}"
-            )
+            self.__extremes_kwargs["threshold"] = kwargs.get("threshold")
+            self.__extremes_kwargs["r"] = pd.to_timedelta(kwargs.get("r", "24H"))
         logger.info("successfully collected extreme value properties")
 
         logger.debug("creating extremes transformer")
@@ -578,9 +550,9 @@ class EVA:
         else:
             if extremes.name != self.data.name:
                 raise ValueError("`extremes` name doesn't match that of `data`")
-        if not (
-            (extremes.index.min() >= self.data.index.min())
-            and (extremes.index.max() <= self.data.index.max())
+        if (
+            extremes.index.min() < self.data.index.min()
+            or extremes.index.max() > self.data.index.max()
         ):
             raise ValueError("`extremes` time range must fit within that of data")
 
@@ -628,7 +600,7 @@ class EVA:
                         "`min_last_block` must be a number in the [0, 1] range"
                     )
 
-        elif method == "POT":
+        else:
             # Get `threshold`
             extremes_kwargs["threshold"] = kwargs.pop(
                 "threshold",
@@ -653,9 +625,6 @@ class EVA:
                     "`r` must be a positive timedelta, not %s" % extremes_kwargs["r"]
                 )
 
-        else:
-            raise RuntimeError
-
         # Check for unrecognized kwargs
         if len(kwargs) != 0:
             raise TypeError(
@@ -696,7 +665,7 @@ class EVA:
 
         """
         model = cls(data=extremes)
-        model.set_extremes(extremes=extremes, **kwargs)
+        model.set_extremes(extremes=model.data, **kwargs)
         return model
 
     def plot_extremes(
@@ -917,7 +886,7 @@ class EVA:
             **kwargs,
         )
 
-    def _get_mcmc_plot_inputs(self, labels=None) -> tuple:
+    def _get_mcmc_plot_inputs(self, labels=None) -> tuple:  # pragma: no cover
         try:
             trace = self.model.trace
             trace_map = tuple(
@@ -1014,8 +983,9 @@ class EVA:
         figure : matplotlib.figure.Figure
             Figure object.
         axes : list
-            2D list with Axes objects
-            of size N by N, where N is n_parameters.
+            2D list with Axes objects of size N by N, where N is `trace.shape[2]`.
+            Empty slots are represented by None. Axes are ordered from left to right
+            top to bottom.
 
         """
         trace, trace_map, labels = self._get_mcmc_plot_inputs(labels=labels)
