@@ -393,16 +393,23 @@ class TestEVA:
             "POT": {"floc": 1.35},
         }[extremes_params["method"]]
         assert eva_model.distribution.name in distributions
-        aic = [
+        models = [
             get_model(
                 model="MLE",
                 extremes=eva_model.extremes,
                 distribution=distribution,
                 distribution_kwargs=distribution_kwargs,
-            ).AIC
+            )
             for distribution in distributions
         ]
-        assert np.isclose(eva_model.AIC, min(aic))
+        assert np.isclose(
+            eva_model.loglikelihood,
+            min(models, key=lambda x: x.AIC).loglikelihood,
+        )
+        assert np.isclose(
+            eva_model.AIC,
+            min(models, key=lambda x: x.AIC).AIC,
+        )
 
     def test_fit_model_errors(self, eva_model_bm, eva_model_pot):
         # Bad distribution type
@@ -492,19 +499,6 @@ class TestEVA:
                     == input_parameters["distribution_kwargs"]["floc"]
                 )
 
-    def test_get_mcmc_plot_inputs(self, eva_model_bm_mle, eva_model_bm_emcee):
-        # Test trying to plot MCMC-only plots for MLE model
-        with pytest.raises(TypeError, match=r"this method.*MCMC-like"):
-            eva_model_bm_mle.plot_trace()
-        with pytest.raises(TypeError, match=r"this method.*MCMC-like"):
-            eva_model_bm_mle.plot_corner()
-
-        # Test default behaviour
-        trace, trace_map, labels = eva_model_bm_emcee._get_mcmc_plot_inputs()
-        assert np.allclose(trace, eva_model_bm_emcee.model.trace)
-        assert len(trace_map) == len(eva_model_bm_emcee.distribution.free_parameters)
-        assert labels == [r"Shape, $\xi$", r"Location, $\mu$", r"Scale, $\sigma$"]
-
     @pytest.mark.parametrize("extremes_method", ["BM", "POT"])
     def test_get_return_value(
         self, eva_model_bm_mle, eva_model_pot_mle, extremes_method
